QuestionnaireBloc class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isClosed → bool
-
Whether the bloc is closed.
no setterinherited
- originalQuestionnaire ↔ String?
-
getter/setter pair
- qestionnaryOption ↔ QuestionnaireOption?
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- state → QuestionnaireState
-
The current state.
no setterinherited
-
stream
→ Stream<
QuestionnaireState> -
The current stream of states.
no setterinherited
Methods
-
addError(
Object error, [StackTrace? stackTrace]) → void -
Reports an
errorwhich triggersonErrorwith an optional StackTrace.inherited -
close(
) → Future< void> -
Closes the instance.
This method should be called when the instance is no longer needed.
Once
closeis called, the instance can no longer be used.inherited -
emit(
QuestionnaireState state) → void -
Updates the
stateto the providedstate.emitdoes nothing if thestatebeing emitted is equal to the currentstate.inherited -
loadedWebView(
) → void -
loadQuestionnaries(
String patientId, {String? questionnaires}) → void -
loadQuestionnariesFromFile(
String patientId) → Future< List< QuestionnaireOption> > -
loadQuestionnariesFromJson(
String patientId, String questionnaires) → Future< List< QuestionnaireOption> > -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
onChange(
Change< QuestionnaireState> change) → void -
Called whenever a
changeoccurs with the givenchange. Achangeoccurs when a newstateis emitted.onChangeis called before thestateof thecubitis updated.onChangeis a great spot to add logging/analytics for a specificcubit.inherited -
onError(
Object error, StackTrace stackTrace) → void -
Called whenever an
erroroccurs and notifiesBlocObserver.onError.inherited -
saveQuestionnaire(
String response, QuestionnaireOption option) → void -
selectQuestionnaire(
QuestionnaireOption option) → void -
toggleEdit(
bool enableEdit) → void -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited